@@ -3,6 +3,7 @@
 /// See https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=872271 for
 /// the motivation.
 
+use std::io;
 use std::process::exit;
 use std::path::PathBuf;
 
@@ -26,10 +27,11 @@ use crate::openpgp::parse::stream::{
     VerificationHelper,
     GoodChecksum,
     VerificationError,
+    VerifierBuilder,
 };
 use crate::openpgp::cert::prelude::*;
 
-mod sqv_cli;
+mod cli;
 
 struct VHelper {
     not_before: Option<std::time::SystemTime>,
@@ -201,6 +203,23 @@ impl VerificationHelper for VHelper {
                                     verification_err = Some(error)
                                 }
                             }
+
+                            Err(UnknownSignature { sig, .. }) => {
+                                eprintln!("Verifying signature:");
+                                print_error_chain(sig.error());
+                                if verification_err.is_none() {
+                                    verification_err =
+                                        Some(anyhow::anyhow!("{}", sig.error()));
+                                }
+                            }
+
+                            Err(e) => {
+                                eprintln!("Verifying signature: {}", e);
+                                if verification_err.is_none() {
+                                    verification_err =
+                                        Some(anyhow::anyhow!("{}", e));
+                                }
+                            }
                         }
                     }
                 MessageLayer::Compression { .. } => (),
@@ -230,12 +249,16 @@ fn print_error_chain(err: &anyhow::Error) {
 
 
 fn main() -> Result<()> {
-    let mut p = sequoia_policy_config::ConfiguredStandardPolicy::new();
-    p.parse_default_config()?;
-    let p = p.build();
+    let matches = cli::build().get_matches();
+    let cli = cli::SqvCommand::from_arg_matches(&matches)?;
 
-    let matches = sqv_cli::build().get_matches();
-    let cli = sqv_cli::SqvCommand::from_arg_matches(&matches)?;
+    if cli.data.is_none() && cli.detached.is_none()
+        && ! cli.message && ! cli.cleartext
+    {
+        return Err(anyhow::anyhow!(
+            "Either `--signature-file`, `--message`, or `--cleartext` \
+             must be given."));
+    }
 
     let verbose = cli.verbose;
 
@@ -265,11 +288,44 @@ fn main() -> Result<()> {
 
     let h = VHelper::new(good_threshold, not_before, not_after, cli.keyring);
 
-    let mut v =
-        DetachedVerifierBuilder::from_file(cli.sig_file)?.with_policy(&p, None, h)?;
-    v.verify_file(cli.file)?;
+    let t = cli.policy_as_of.as_ref()
+        .map(|at| at.to_system_time(std::time::SystemTime::now()))
+        .transpose()
+        .with_context(|| format!("Error parsing --policy-as-of: {}",
+                                 cli.policy_as_of.unwrap()))?
+        .unwrap_or_else(std::time::SystemTime::now);
 
-    let h = v.into_helper();
+    let mut p = sequoia_policy_config::ConfiguredStandardPolicy::at(t);
+    p.parse_default_config()?;
+    let p = p.build();
+
+    // Dispatch.
+    let h = if cli.data.is_some() || cli.detached.is_some() {
+        let sig = cli.detached.as_ref().unwrap_or(&cli.file);
+        let data = cli.data.as_ref().unwrap_or(&cli.file);
+
+        let mut v =
+            DetachedVerifierBuilder::from_file(sig)?
+            .with_policy(&p, None, h)?;
+        v.verify_file(data)?;
+        v.into_helper()
+    } else {
+        assert!(cli.message || cli.cleartext);
+        let mut sink: Box<dyn io::Write> = if let Some(n) = &cli.output {
+            Box::new(std::fs::File::options()
+                     .write(true)
+                     .create_new(true)
+                     .open(n)?)
+        } else {
+            Box::new(io::stdout())
+        };
+
+        let mut v =
+            VerifierBuilder::from_file(&cli.file)?
+            .with_policy(&p, None, h)?;
+        io::copy(&mut v, &mut sink)?;
+        v.into_helper()
+    };
 
     if verbose {
         eprintln!("{} of {} signatures are valid (threshold is: {}).",
