@@ -1,5 +1,5 @@
 
-use assert_cli::Assert;
+use assert_cmd::Command;
 
 fn p(filename: &str) -> String {
     format!("../openpgp/tests/data/{}", filename)
@@ -11,13 +11,13 @@ fn p(filename: &str) -> String {
 fn ignore_multiple_signatures() {
     // Multiple signatures from the same Cert are ignored, and fails to
     // meet the threshold.
-    Assert::cargo_binary("sqv")
-        .with_args(
+    Command::cargo_bin("sqv").expect("have sqv")
+        .args(
             &["--keyring",
               &p("keys/emmelie-dorothea-dina-samantha-awina-ed25519.pgp"),
               "--signatures=2",
               &p("messages/a-cypherpunks-manifesto.txt.ed25519.sig.duplicated"),
               &p("messages/a-cypherpunks-manifesto.txt")])
-        .fails()
-        .unwrap();
+        .assert()
+        .failure();
 }
